from setuptools import setup


setup(
    name = 'odatoo',
    packages = ['odatoo', 'tests'],
    version = '0.3',
    description = 'Odoo XML data files library',
    author = 'Will Earp',
    author_email = 'will.earp@icloud.com',
    url = 'https://github.com/wearp/odatoo',
    download_url = 'https://github.com/wearp/odatoo/tarball/0.3',
    keywords = ['odoo', 'xml', 'data', 'files'],
)
